{% load admin_urls %}
{% if audit_trail.is_related_changed %} {{ audit_trail.related_trail.content_type|capfirst }} "{{ audit_trail.related_trail.object_repr }}" was {{ audit_trail.related_trail.get_action_display|lower }} {% with audit_trail=audit_trail.related_trail changes=audit_trail.related_trail.get_changes %} {% include "audit_trail/changes.html" %} {% endwith %} {% else %}

{% for field_label, change in changes.items|slice:":6" %} {% include "audit_trail/change_row.html" %} {% endfor %} {% if changes|length > 6 %}
Show more
{% for field_label, change in changes.items|slice:"6:" %} {% include "audit_trail/change_row.html" %} {% endfor %}
{% endif %}

{% endif %}